#!/usr/bin/python

import os, os.path, sys, shutil, optparse

sys_firmware_dir = '/lib/firmware'

def copy_firmware( from_dir, to_dir, check_dir ):
    for entry in os.listdir( from_dir ):
        src = os.path.join( from_dir, entry )
        dest = os.path.join( to_dir, entry )
        check = os.path.join( check_dir, entry )
        if os.path.isdir( src ):
           copy_firmware( src, dest, check )
        if os.path.isfile( src ):
            if not os.path.exists( check ):
                if not os.path.exists( to_dir ):
                    os.makedirs( to_dir )
                if os.path.exists( dest ):
                    print "Warning: firmware", dest, "already exists!"
                shutil.copyfile( src, dest )
                shutil.copystat( src, dest )

def copy_modules( from_dir, to_dir ):
    if not os.path.exists( to_dir ):
        os.makedirs( to_dir )
    for entry in os.listdir( from_dir ):
        src = os.path.join( from_dir, entry )
        dest = os.path.join( to_dir, entry )
        if os.path.isdir( src ):
           copy_modules( src, to_dir )
        if os.path.isfile( src ):
            if os.path.exists( dest ):
                print "Warning: module", dest, "already exists!"
            shutil.copyfile( src, dest )
            shutil.copystat( src, dest )

def make_overrides( modules_dir, depmod_conf_filename ):
    weak_updates_dir_name = os.path.basename( os.path.abspath( modules_dir ) )
    depmod_conf_file_dirname = os.path.dirname( os.path.abspath( depmod_conf_filename ) )
    if not os.path.exists( depmod_conf_file_dirname ):
        os.makedirs( depmod_conf_file_dirname )
    depmod_conf_file = open( depmod_conf_filename, 'w' )
    for entry in sorted( os.listdir( modules_dir ) ):
        module_name = entry.split( '.' )[ 0 ]
        line = "override %s * weak-updates/%s\n" % ( module_name, weak_updates_dir_name )
        depmod_conf_file.write( line )
    depmod_conf_file.close()

if __name__=='__main__':
    parser = optparse.OptionParser( usage = 'usage: %prog <option> <src> <dest>', prog = os.path.basename( sys.argv[ 0 ] ) )
    parser.add_option( '-f', '--copy-firmware', dest='copy_firmware', action='store_true', help='copy firmware from_dir to_dir' )
    parser.add_option( '-m', '--copy-modules', dest='copy_modules', action='store_true', help='copy modules from_dir to_dir' )
    parser.add_option( '-o', '--make-overrides', dest='make_overrides', action='store_true', help='make overrides from_dir to_file' )
    ( options, args ) = parser.parse_args()
    if vars( options ).values().count( True ) != 1 or len( args ) != 2:
        parser.print_help()
        print
        sys.exit( 1 )
    else:
        src, dest = args
        if options.copy_firmware: copy_firmware( src, dest, sys_firmware_dir )
        if options.copy_modules: copy_modules( src, dest )
        if options.make_overrides: make_overrides( src, dest )

