
#
# KNOWN BUGS:
#
# ==============================================================================================================
#
# 1. /lib/firmware conflict/collision during rpm build process:
#
# if old version of package kmod-video4linux already installed,
# build of the new version of this package will fail with error:
# File not found: /home/rpmbuild/rpmbuild/BUILDROOT/video4linux-kmod-1.0.0-1.20120309.el6.cs.i386/lib/firmware
#
# WORKAROUND: remove old installed version of kmod-video4linux package before building new one.
#
# COMPLETE SOLUTION: none at this moment.
#
# ==============================================================================================================
#
# 2. warning messages about unknown symbols during rpm install process:
#
# if kmod-alsa 1.0.25 installed:
# 
# # yum install kmod-video4linux
#   Installing : kmod-video4linux-0.0-1.20120309.el6.cs.i686
# Working. This may take some time ...
# WARNING: /lib/modules/2.6.32-220.7.1.el6.i686/kernel/drivers/media/video/soc_camera.ko needs unknown symbol video_device_shadow_get
# WARNING: /lib/modules/2.6.32-220.7.1.el6.i686/kernel/drivers/media/video/soc_camera.ko needs unknown symbol video_register_device
# WARNING: /lib/modules/2.6.32-220.7.1.el6.i686/weak-updates/alsa/snd-tea575x-tuner.ko needs unknown symbol video_register_device
# Done.
#
# if kmod-alsa 1.0.25 not installed:
#
# Working. This may take some time ...
# WARNING: /lib/modules/2.6.32-220.7.1.el6.i686/kernel/drivers/media/video/soc_camera.ko needs unknown symbol video_device_shadow_get
# WARNING: /lib/modules/2.6.32-220.7.1.el6.i686/kernel/drivers/media/video/soc_camera.ko needs unknown symbol video_register_device
# WARNING: /lib/modules/2.6.32-220.7.1.el6.i686/weak-updates/video4linux/radio-miropcm20.ko needs unknown symbol snd_aci_cmd
# WARNING: /lib/modules/2.6.32-220.7.1.el6.i686/weak-updates/video4linux/radio-miropcm20.ko needs unknown symbol snd_aci_get_aci
# WARNING: /lib/modules/2.6.32-220.7.1.el6.i686/weak-updates/video4linux/radio-sf16fmr2.ko needs unknown symbol snd_tea575x_exit
# WARNING: /lib/modules/2.6.32-220.7.1.el6.i686/weak-updates/video4linux/radio-sf16fmr2.ko needs unknown symbol snd_tea575x_init
# Done.
#
# WORKAROUND: just ignore these messages, other modules should work fine.
#
# COMPLETE SOLUTION: none at this moment.
#
# ==============================================================================================================
#
# 3. probably kmod-alsa 1.0.25 should be installed before building kmod-video4linux package,
#    and kmod-video4linux also should be installed before building kmod-alsa.
#
#    ( not tested/verified right now, this is just supposition )
#
# ==============================================================================================================
#

%define kmod_name video4linux
%define media_build_date 2012-03-15
%define linux_media_date 2012-03-09
%define linux_media_vers 20120309

# If kversion isn't defined on the rpmbuild line, define it here.
%{!?kversion: %define kversion 2.6.32-220.el6.%{_target_cpu}}

Name:    %{kmod_name}-kmod
Version: 0.0
Release: 1.%{linux_media_vers}%{?dist}
Group:   System Environment/Kernel
License: GPLv2
Summary: %{kmod_name} kernel module(s)
URL:     http://www.kernel.org/

BuildRequires: redhat-rpm-config
BuildRequires: patchutils
BuildRequires: kernel-firmware
BuildRequires: python
BuildRequires: perl-Proc-ProcessTable

ExclusiveArch: i686 x86_64

# Sources.

# git clone git://linuxtv.org/media_build.git
# cd media_build
# tar -cjf ../media-build-%{media_build_date}.tar.bz2 .

Source0:  media-build-%{media_build_date}.tar.bz2
Source1:  http://www.linuxtv.org/downloads/drivers/linux-media-%{linux_media_date}.tar.bz2
Source2:  http://www.linuxtv.org/downloads/firmware/dvb-firmwares.tar.bz2

Source5:  GPL-v2.0.txt
Source10: kmodtool-%{kmod_name}-el6.sh
Source20: kmodtool-%{kmod_name}-el6.py

# Magic hidden here.
%{expand:%(sh %{SOURCE10} rpmtemplate %{kmod_name} %{kversion} "")}

# Disable the building of the debug package(s).
%define debug_package %{nil}

%description
This package provides the %{kmod_name} kernel module(s).
It is built to depend upon the specific ABI provided by a range of releases
of the same variant of the Linux kernel and not on any one specific build.

%prep
%setup -q -a0 -c %{kmod_name}-%{version}
%{__tar} -xjf %{SOURCE1} -C linux/
%{__tar} -xjf %{SOURCE2} -C v4l/firmware/

%build
%{__make} DIR=%{_usrsrc}/kernels/%{kversion} allyesconfig
%{__make} DIR=%{_usrsrc}/kernels/%{kversion}

%install
%{__rm} -rf %{buildroot}
%{__make} DESTDIR="%{buildroot}/tmp" install
python %{SOURCE20} --copy-firmware "%{buildroot}/tmp/lib/firmware" "%{buildroot}/lib/firmware"
python %{SOURCE20} --copy-modules "%{buildroot}/tmp/lib/modules/%{kversion}/kernel" "%{buildroot}/lib/modules/%{kversion}/extra/%{kmod_name}"
python %{SOURCE20} --make-overrides "%{buildroot}/lib/modules/%{kversion}/extra/%{kmod_name}" "%{buildroot}%{_sysconfdir}/depmod.d/kmod-%{kmod_name}.conf"
%{__rm} -rf "%{buildroot}/tmp"
%{__install} -d %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/
%{__install} %{SOURCE5} %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/COPYING
# Set the module(s) to be executable, so that they will be stripped when packaged.
find %{buildroot} -type f -name \*.ko -exec %{__chmod} u+x \{\} \;
# Remove the unrequired files.
%{__rm} -f %{buildroot}/lib/modules/%{kversion}/modules.*

%clean
%{__rm} -rf %{buildroot}

%changelog
* Fri Mar 16 2012 Gena Makhomed <gmm@csdoc.com> - 0.0-1
- Initial el6 build of the kmod package.
- Added BuildRequires perl-Proc-ProcessTable (Akemi Yagi <toracat@elrepo.org>).

